@@ -28,7 +28,7 @@ class SoftwarePilot:
 		gets the host's ip address
 	'''
 	def __init__(self):
-		self.drone_lib_dict = {"parrot-anafi" : "AnafiController"}
+		self.drone_lib_dict = {"parrot_anafi" : "AnafiController"}
 	
 	def setup_drone(self, drone_type, connection_method, download_dir="None"):
 		'''
